package emotionkb.live.offcn.com.emotionkeyboard;

import android.content.Context;
import android.os.Build;
import android.support.annotation.Nullable;
import android.support.annotation.RequiresApi;
import android.support.v4.view.ViewPager;
import android.support.v7.widget.GridLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.LinearLayout;

import com.viewpagerindicator.CirclePageIndicator;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import emotionkb.live.offcn.com.emotionkeyboard.adapter.ZGLEmotionAdapter;
import emotionkb.live.offcn.com.emotionkeyboard.adapter.ZGLEmotionPagerAdapter;

/**
 * 表情键盘
 *
 * @author wangwenlong
 * @date 2018/8/30
 */
public class ZGLInputEmotionView extends LinearLayout {

    ViewPager mViewPager;
    CirclePageIndicator mPageIndicator;

    // 每页表情个数。留个位置给删除按钮
    private static final int PAGE_SIZE = 20;
    // 表情个数数量
    private static final int TOTAL_COUNT = 48;

    private List<View> mViewPagerViewList = new ArrayList<>();

    public ZGLInputEmotionView(Context context) {
        super(context);
        init(context);
    }

    public ZGLInputEmotionView(Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }

    public ZGLInputEmotionView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init(context);
    }

    @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
    public ZGLInputEmotionView(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        init(context);
    }


    private void init(Context context) {
        View view = LayoutInflater.from(context).inflate(R.layout.zgl_view_emotion, null);
        addView(view);

        mViewPager = findViewById(R.id.view_pager);
        mPageIndicator = findViewById(R.id.circle_indi);
        mPageIndicator.setStrokeWidth(0);
        mPageIndicator.setFillColor(getResources().getColor(android.R.color.black));
//        mPageIndicator.setPageColor(getResources().getColor(R.color.color_99999a));

        initViewPager();
    }

    private void initViewPager() {
        try {
            // 获取emoji目录下的表情
//            String[] emotions = getContext().getAssets().list("emoji");
//            if (emotions == null || emotions.length == 0) {
//                return;
//            }
//
//            // 通过表情个数，获取页数
//            int pageCount = emotions.length / PAGE_SIZE + 1;


            // 上面是很灵活的实现方式，但图片大小显示会有适配问题，所以暂时用 xhdpi 的方式来实现
            // 需要固定好个数
            String formatEmotionName = "face_%d.png";
            int pageCount = TOTAL_COUNT / PAGE_SIZE;
            if (TOTAL_COUNT % PAGE_SIZE != 0) {
                ++pageCount;
            }
            for (int i = 0; i < pageCount; i++) {
                RecyclerView view = new RecyclerView(getContext());
                GridLayoutManager gridLayoutManager = new GridLayoutManager(getContext(), 7);
                view.setLayoutManager(gridLayoutManager);

                List<String> tmp = new ArrayList<>();
                int limit = i + 1;
                for (int j = PAGE_SIZE * i; j < PAGE_SIZE * limit && j < TOTAL_COUNT; j++) {
//                    tmp.add(emotions[j]);
                    tmp.add(String.format(Locale.CHINA, formatEmotionName, j));
                }
                view.setAdapter(new ZGLEmotionAdapter(getContext(), tmp));

                mViewPagerViewList.add(view);
            }

            mViewPager.setAdapter(new ZGLEmotionPagerAdapter(mViewPagerViewList));
            mPageIndicator.setViewPager(mViewPager);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
