package emotionkb.live.offcn.com.emotionkeyboard.adapter;

import android.content.Context;
import android.os.Handler;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.DecelerateInterpolator;
import android.widget.AdapterView;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;


public abstract class BaseRecyclerViewAdapter<T> extends RecyclerView.Adapter<BaseRecyclerViewHolder> {
    protected List<T> mList;
    protected Context mContext;

    public BaseRecyclerViewAdapter(Context paramContext) {
        this.mContext = paramContext;
        this.mList = new ArrayList<T>();
    }

    public BaseRecyclerViewAdapter(Context context, List<T> list) {
        this.mList = list;
        this.mContext = context;
    }

    @Override
    public BaseRecyclerViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(mContext).inflate(onCreateViewLayoutID(viewType), parent, false);
        return new BaseRecyclerViewHolder(view);
    }

    public abstract int onCreateViewLayoutID(int viewType);


    @Override
    public void onViewRecycled(BaseRecyclerViewHolder holder) {
        super.onViewRecycled(holder);
    }

    @Override
    public void onBindViewHolder(final BaseRecyclerViewHolder holder, final int position) {
        bindItemViewHolder(holder.getViewHolder(), position);
        if (onItemClickListener != null) {
            holder.itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    onItemClickListener.onItemClick(null, v, holder.getPosition(), holder.getItemId());
                }
            });
        }
    }

    /**
     * 展示数据
     */
    public abstract void bindItemViewHolder(RecyclerViewHolderUtil holder, int position);

    protected int getBasicItemCount() {
        if (null == mList || mList.size() == 0) {
            return 0;
        }
        return mList.size();
    }

    @Override
    public int getItemCount() {
        return getBasicItemCount();
    }


    private AdapterView.OnItemClickListener onItemClickListener;

    public AdapterView.OnItemClickListener getOnItemClickListener() {
        return onItemClickListener;
    }

    public void setOnItemClickListener(AdapterView.OnItemClickListener onItemClickListener) {
        this.onItemClickListener = onItemClickListener;
    }

    public T getItem(int paramInt) {
        if (null != mList && mList.size() != 0 && paramInt < mList.size()) {
            return this.mList.get(paramInt);
        } else {
            return null;
        }
    }

    public void add(T paramT) {
        add(0, paramT);
    }

    public void addLast(T paramT) {
        this.mList.add(paramT);
        notifyDataSetChanged();
    }

    @SuppressWarnings("SameParameterValue")
    public void add(final int paramInt, T paramT) {
        this.mList.add(paramInt, paramT);
        // 保有插入的动画效果，用handler不会报错
        if (paramInt == 0) {
            notifyDataSetChanged();
        } else {
            new Handler().post(new Runnable() {
                @Override
                public void run() {
                    notifyItemInserted(paramInt);
                }
            });
        }
    }

    public void addAll(Collection<T> paramT) {
        this.mList.addAll(paramT);
        notifyDataSetChanged();
    }

    public void remove(int position) {
        this.mList.remove(position);
        notifyItemRemoved(position);
    }

    public void remove(T t) {
        this.mList.remove(t);
        notifyDataSetChanged();
    }

    @SuppressWarnings("SameParameterValue")
    public void addAll(int paramInt, Collection<T> paramT) {
        this.mList.addAll(paramInt, paramT);
        notifyDataSetChanged();
    }

    public void clear() {
        this.mList.clear();
        notifyDataSetChanged();
    }

    public List<T> getList() {
        return this.mList;
    }

    private int lastAnimatedPosition = -1;

    protected void runEnterAnimation(View view, int position, int height) {
        if (position < 0) {
            return;
        }

        if (position > lastAnimatedPosition) {
            lastAnimatedPosition = position;
            view.setTranslationY(height);
            if (position <= 20) {
                view.animate()
                        .translationY(0)
                        .setInterpolator(new DecelerateInterpolator(3.f))
                        .setDuration(500)
                        .setStartDelay(position * 20)
                        .start();
            } else {
                view.animate()
                        .translationY(0)
                        .setInterpolator(new DecelerateInterpolator(3.f))
                        .setDuration(500)
                        .start();
            }
        }
    }
}